@@ -419,7 +419,7 @@ trilobite_service_initialize (TrilobiteService *trilobite)
 
 	corba_trilobite = trilobite_service_create_corba_object (BONOBO_OBJECT (trilobite));
 	
-	if (trilobite_service_construct (trilobite, corba_trilobite) == FALSE) {
+	if (!trilobite_service_construct (trilobite, corba_trilobite)) {
 		trilobite_service_destroy (GTK_OBJECT (trilobite));
 		trilobite = NULL;
 	} 
@@ -475,7 +475,7 @@ trilobite_service_new()
 
 	/* g_message ("in trilobite_service_new"); */
 
-	trilobite = TRILOBITE_SERVICE (gtk_type_new (TRILOBITE_TYPE_SERVICE));
+	trilobite = TRILOBITE_SERVICE (gtk_object_new (TRILOBITE_TYPE_SERVICE, NULL));
 
 	if (trilobite == NULL) {
 		g_warning ("Could not create a TrilobiteService*");
