@@ -384,7 +384,7 @@ nautilus_run_simple_dialog (GtkWidget *parent, gboolean ignore_close_box,
 	/* Parent it if asked to. */
         if (parent != NULL) {
 		top_widget = gtk_widget_get_toplevel (parent);
-		if (GTK_IS_WINDOW (top_widget)) {
+		if (GTK_IS_WINDOW (top_widget) && !GTK_OBJECT_DESTROYED (top_widget)) {
 			gnome_dialog_set_parent (GNOME_DIALOG (dialog), GTK_WINDOW (top_widget));
 		}
 	}
@@ -455,10 +455,13 @@ create_message_box (const char *message,
 	 * for the label with this message so we can mark it.
 	 */
 	find_message_label (box, message);
-	message_label = GTK_LABEL (gtk_object_get_data (GTK_OBJECT (box), "message label"));
-	gtk_label_set_line_wrap (message_label, TRUE);
+	message_label = gtk_object_get_data (GTK_OBJECT (box), "message label");
+	
+	if (message_label != NULL && GTK_IS_LABEL (message_label)) {
+		gtk_label_set_line_wrap (message_label, TRUE);
+	}
 
-	if (parent != NULL) {
+	if (parent != NULL && !GTK_OBJECT_DESTROYED (parent)) {
 		gnome_dialog_set_parent (GNOME_DIALOG (box), parent);
 	}
 	return GNOME_DIALOG (box);
